#[non_exhaustive]pub enum IsleError {
Shutdown,
Cancelled,
Lua(String),
ThreadPanic,
RecvFailed(String),
Init(String),
}Expand description
Errors returned by Isle operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Shutdown
The Lua VM thread has already shut down.
Cancelled
The operation was cancelled via CancelToken.
Lua(String)
A Lua runtime error.
ThreadPanic
The Lua thread panicked.
RecvFailed(String)
Failed to receive response from the Lua thread.
The oneshot / mpsc response channel was dropped before a result was sent. This typically means the Lua thread panicked or was shut down while a request was in flight.
Init(String)
Error during Isle initialization.